<?php

namespace Drupal\menu_reference_render\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceFormatterBase;

/**
 * Plugin implementation of the 'menu_reference_render' formatter.
 *
 * @FieldFormatter(
 *   id = "menu_reference_render",
 *   label = @Translation("Rendered menu"),
 *   field_types = {
 *     "entity_reference"
 *   }
 * )
 */
class MenuReferenceFormatter extends EntityReferenceFormatterBase {

	/**
	 * {@inheritdoc}
	 */
	public function viewElements(FieldItemListInterface $items, $langcode) {
		$elements = [];

		foreach ($this->getEntitiesToView($items, $langcode) as $delta => $entity) {
			$menu_name = $entity->get('id');
			$menu_tree = \Drupal::menuTree();

			// Build the typical default set of menu tree parameters.
			$parameters = $menu_tree->getCurrentRouteMenuTreeParameters($menu_name);

			// Load the tree based on this set of parameters.
			$tree = $menu_tree->load($menu_name, $parameters);

			$elements[] = $menu_tree->build($tree);
		}

		return $elements;
	}

}
